.. atmosphere:

Atmosphere
==========

.. autosummary::
    :toctree: generated/

    sasktran2.Atmosphere

Internal Objects
----------------

.. autosummary::
    :toctree: generated/

    sasktran2.AtmosphereStokes_1
    sasktran2.AtmosphereStokes_3

    sasktran2.AtmosphereStorageStokes_1
    sasktran2.AtmosphereStorageStokes_3
